import{l as d,J as v,r as i,B as n,O as o,S as y,b as m,o as E,af as s,q as I,v as A}from"./index-a5bb9833.js";import{_ as D}from"./ItemsListing.vue_vue_type_script_setup_true_lang-83c47556.js";import"./ListviewItem-e2342ce8.js";import"./MediaItemThumb.vue_vue_type_style_index_0_lang-a35ce75a.js";import"./VMenu-240a4406.js";import"./VDivider-df9414f0.js";import"./VBtn-629f5316.js";import"./VListItem-39677d21.js";import"./Container-4773c160.js";/* empty css              */import"./VDialog-667c0916.js";import"./VCard-04ae357c.js";import"./VToolbar-b79315e8.js";import"./VSelect-4d69c543.js";/* empty css                             */import"./PanelviewItem.vue_vue_type_style_index_0_lang-d218249a.js";import"./Alert-a5ce795e.js";import"./VBadge-f7d58168.js";import"./VRow-7d86481a.js";const z=d({__name:"LibraryArtists",setup(M){const{t:p}=v(),l=i([]),r=i(!1),u=async function(t,a,e,c,_=!0,f=!0){const b=_||void 0;return r.value=!1,await o.getLibraryArtists(b,c,a,t,e,f)};return n.topBarContextMenuItems=[{label:"sync_now",labelArgs:[p("artists")],action:()=>{o.startSync([y.ARTIST])},icon:"mdi-sync"}],m(()=>{n.topBarContextMenuItems=[]}),E(()=>{const t=o.subscribe_multi([s.MEDIA_ITEM_ADDED,s.MEDIA_ITEM_UPDATED,s.MEDIA_ITEM_DELETED],a=>{var e;(e=a.object_id)!=null&&e.startsWith("library://artist")&&(r.value=!0)});m(t)}),(t,a)=>(I(),A(D,{itemtype:"artists",items:l.value,"show-provider":!1,"show-favorites-only-filter":!0,"load-data":u,"show-album-artists-only-filter":!0,"update-available":r.value},null,8,["items","update-available"]))}});export{z as default};
